@@ -9,9 +9,10 @@ from slumber.connector import Client, DictObject
 from slumber.connector.ua import get
 
 from slumber_examples.models import Pizza, PizzaPrice, PizzaSizePrice
+from slumber_examples.tests.configurations import ConfigureUser
 
 
-class TestDirectoryURLs(TestCase):
+class TestDirectoryURLs(ConfigureUser, TestCase):
     def test_get_default_url_with_made_client(self):
         client = Client()
         self.assertEqual('http://localhost:8000/slumber/', client._directory)
@@ -27,14 +28,14 @@ class TestDirectoryURLs(TestCase):
         self.assertIsNone(client._directory)
 
 
-class TestLoads(TestCase):
+class TestLoads(ConfigureUser, TestCase):
 
     def test_applications_local(self):
         client = Client('http://localhost:8000/slumber')
         self.assertTrue(hasattr(client, 'slumber_examples'))
 
     def test_applications_remote(self):
-        def request(k, u):
+        def request(k, u, headers):
             self.assertEquals(u, 'http://slumber.example.com/')
             return DictObject(status=200), '''{"apps":{}}'''
         with patch('slumber.connector.ua.Http.request', self.fail):
@@ -76,26 +77,25 @@ class TestLoads(TestCase):
             pass
 
     def test_can_create_instance(self):
+        self.user.is_superuser = True
+        self.user.save()
         rpizza = client.slumber_examples.Pizza.create(
             name='P1', for_sale=True)
         lpizza = Pizza.objects.get(name='P1')
         self.assertEquals(rpizza.id, lpizza.id)
 
 
-class TestAuth(TestCase):
-    def setUp(self):
-        self.u = User(username='user')
-        self.u.save()
-
+class TestAuth(ConfigureUser, TestCase):
     def test_has_attributes(self):
-        user = client.django.contrib.auth.User.get(pk=self.u.pk)
+        user = client.django.contrib.auth.User.get(pk=self.user.pk)
         for attr in ['is_active', 'is_staff', 'date_joined', 'is_superuser',
                 'first_name', 'last_name', 'email', 'username']:
             self.assertTrue(hasattr(user, attr), user.__dict__.keys())
 
 
-class TestsWithPizza(TestCase):
+class TestsWithPizza(ConfigureUser, TestCase):
     def setUp(self):
+        super(TestsWithPizza, self).setUp()
         self.s = Pizza(name='S1', for_sale=True)
         self.s.save()
         self.pizza = client.slumber_examples.Pizza.get(pk=self.s.pk)
@@ -172,11 +172,12 @@ class TestsWithPizza(TestCase):
             p2 = client.slumber_examples.Pizza.get(pk=2)
 
 
-class AppServiceTests(TestCase):
+class AppServiceTests(ConfigureUser, TestCase):
     """Used to get service view tests where the service is configured
     on the application.
     """
     def setUp(self):
+        super(AppServiceTests, self).setUp()
         pizzas = lambda: 'pizzas'
         directory = lambda: {
                 'auth': 'django.contrib.auth',
@@ -189,6 +190,7 @@ class AppServiceTests(TestCase):
         [p.start() for p in self.__patchers]
     def tearDown(self):
         [p.stop() for p in self.__patchers]
+        super(AppServiceTests, self).tearDown()
 
     def test_directory(self):
         request, json = get('http://localhost:8000/slumber/')
